@@ -66,6 +66,12 @@
 #define TITRAQ_DEFBAKON         1
 #define TITRAQ_PREFEXTENDON     "filextension"
 #define TITRAQ_DEFEXTENDON      1
+#define TITRAQ_PREFREPORTYPE    "reportperiod"
+#define TITRAQ_DEFREPORTYPE     TITRAQ_REPORTWEEK
+#define TITRAQ_PREFREPORTWEEKS  "reportweeks"
+#define TITRAQ_DEFREPORTWEEKS   1
+#define TITRAQ_PREFREPORTMONTHS "reportmonths"
+#define TITRAQ_DEFREPORTMONTHS  1
 
 // Column show preferences
 #define TITRAQ_PREFSTATCOLON    "statcolshow"
@@ -228,6 +234,12 @@
 #define TITRAQ_OFFSETMONTH      7
 #define TITRAQ_OFFSETHOUR       2
 
+// Report periods
+#define TITRAQ_REPORTWEEK       0
+#define TITRAQ_REPORTMONTH      1
+#define TITRAQ_REPORTBOTH       2
+#define TITRAQ_POPUPMSECS       200
+
 // Values
 #define TITRAQ_MARGIN           10          // Default layout margin
 #define TITRAQ_SPACING          6           // Default layout spacing
