@@ -59,12 +59,12 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     // Start of style chooser UI pieces
     m_pBoolpage = new QWidget(m_pTabselect, "Tabpage");
     m_pBoolayout = new QHBoxLayout(m_pBoolpage, 11, 6, "Genlayout"); 
+    m_pBinlayout = new QVBoxLayout(0, 0, 6, "Binarylayout"); 
     m_pStylegroup = new QButtonGroup(m_pBoolpage, "Stylebuttongroup");
     m_pStylegroup->setColumnLayout(0, Qt::Vertical);
     m_pStylegroup->layout()->setSpacing(6);
     m_pStylegroup->layout()->setMargin(11);
     m_pStylegroup->setExclusive(true);
-    m_pBoolayout->addWidget(m_pStylegroup);
 
     m_pStylelay = new QVBoxLayout(m_pStylegroup->layout());
     m_pStylelay->setAlignment(Qt::AlignTop);
@@ -113,7 +113,33 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     QWhatsThis::add(m_pExtendcheck, tr("Check this box to automatically append '.as' to new filenames when saving", "Comment whatsThis for Extensioncheck"));
     m_pSwitchlay->addWidget(m_pExtendcheck);
 
-    m_pBoolayout->addWidget(m_pSwitchgroup);
+    // Start of report option UI pieces (like detailed report listings)
+    m_pReportgroup = new QButtonGroup(m_pBoolpage, "Reportbuttongroup");
+    m_pReportgroup->setColumnLayout(0, Qt::Vertical);
+    m_pReportgroup->layout()->setSpacing(6);
+    m_pReportgroup->layout()->setMargin(11);
+    m_pReportgroup->setExclusive(false);
+    m_pReportlay = new QVBoxLayout(m_pReportgroup->layout());
+    m_pReportlay->setAlignment(Qt::AlignTop);
+
+    // Optional detailed report listings write all events in range
+    m_pDetailcheck = new QCheckBox(m_pReportgroup, "Detailistbutton");
+    m_pDetailcheck->setText(tr("Detailed listing", "Comment for Detailcheck"));
+    QToolTip::add(m_pDetailcheck, tr("Write detailed event listings", "Comment for toolTip Detailcheck"));
+    QWhatsThis::add(m_pDetailcheck, tr("Check this box to enable writing of detailed event listings to the local report", "Comment whatsThis for Detailcheck"));
+    m_pReportlay->addWidget(m_pDetailcheck);
+
+    // Optional signature line in report footer
+    m_pSigncheck = new QCheckBox(m_pReportgroup, "Signaturebutton");
+    m_pSigncheck->setText(tr("Signature line", "Comment for Signaturecheck"));
+    QToolTip::add(m_pSigncheck, tr("Append a signature line", "Comment for toolTip Signaturecheck"));
+    QWhatsThis::add(m_pSigncheck, tr("Check this box to write a signature line to the report footer", "Comment whatsThis for Signaturecheck"));
+    m_pReportlay->addWidget(m_pSigncheck);
+
+    m_pBoolayout->addWidget(m_pStylegroup);
+    m_pBinlayout->addWidget(m_pReportgroup);
+    m_pBinlayout->addWidget(m_pSwitchgroup);
+    m_pBoolayout->addLayout(m_pBinlayout);
     m_pTabselect->insertTab(m_pBoolpage, "");
 
     // Start of paths page UI pieces
@@ -265,10 +291,6 @@ void Prefpanel::textChange(void)
     QWhatsThis::add(m_pSoapcheck, tr("Check this box to enable transmission over to a SOAP host", "Comment whatsThis for Soapcheck"));
 
     m_pStylegroup->setTitle(tr("Available styles", "Comment for Stylebuttons"));
-//    QToolTip::add(m_pStylegroup, tr("Tooltip for Stylebutton", "Comment for toolTip Stylebutton"));
-//    QWhatsThis::add(m_pStylegroup, tr("Whatsthis for Stylebutton", "Comment for whatsThis Stylebuttons"));
-
+    m_pReportgroup->setTitle(tr("Report options", "Comment for Reportbox"));
     m_pSwitchgroup->setTitle(tr("Other options", "Comment for Switchbox"));
-//    QToolTip::add(m_pSwitchgroup, tr("Tooltip for Switchbox", "Comment for toolTip Switchbox"));
-//    QWhatsThis::add(m_pSwitchgroup, tr("Whatsthis for Switchbutton", "Comment for whatsThis Switchbox"));
 }
