@@ -1558,12 +1558,16 @@ void Titraqform::showRemarkcol(void)
 //
 void Titraqform::genReport(void)
 {
-    Reportpanel *pReport = NULL;    // The local report panel
-
-    // Create a new local report window
-    pReport = new Reportpanel(m_pMaintable, m_pPrefs, this, "Locreportpanel");
-    pReport->exec();    // Modal panel handler
-    delete pReport;     // Dispose Panel object
+    try { // Create and execute a new local report window
+        std::auto_ptr<AS::Reportpanel> pReport(new AS::Reportpanel
+            (m_pMaintable, m_pPrefs, this, "Locreportpanel"));
+        pReport->exec();
+        delete pReport.release(); // Technically unnecessary, smart pointer
+    }
+    catch (Genexcept& Genex) {
+        Genex.reportErr();
+        return;
+    }
 }
 
 //
